==> zn-plugin-workflow-0.1.5.tgz: package/web/src/component/WFInstanceList.js <==
var React = require('react');
var CreateInstance = require('./CreateInstance');
module.exports = React.createClass({
	getDefaultProps: function () {
		return {
			model: 'ZNPluginWorkflowInstance'
		};
	},
	getInitialState: function () {
		return {
			data: zn.store.post('/zn.plugin.workflow/wfinstance/getInstances', {
				index_id: this.props.indexId
			}),
			items: [
				{ title: '模块', name: 'index_id_convert', width: 80 },
				{ title: '单号', name: 'code', width: 150 },
				{ title: '状态', name: 'state', width: 80 },
				{ title: '当前节点', name: 'current_state', width: 120 },
				{ title: '申请人', name: 'zn_create_user_convert', width: 100 },
				{ title: '申请时间', name: 'zn_create_time', width: 130 },
				{ title: '最近一次操作时间', name: 'zn_modify_time', width: 130 },
				{ title: '说明', name: 'zn_note' }
			],
			toolbarItems: [
				{ text: '创建实例', name: 'wfinstance.create', icon: 'fa-plus', style: { marginRight: 5 } },
				{ text: '删除实例', name: 'wfinstance.delete', status: 'danger', icon: 'fa-remove', style: { marginRight: 5 } }
			]
		}
	},
	componentWillReceiveProps: function (nextProps){
		if(nextProps.indexId){
			this.state.data.extend({
				index_id: nextProps.indexId
			}).refresh();
		}
	},
	__doSuccess: function (){
		this.state.data.refresh();
	},
	__createInstance: function (){
		zn.dialog({
			title: '创建流程实例',
			content: <CreateInstance id={this.props.indexId} />
		});
	},
	__removeItems: function (){
		var _self = this,
			_values = this.refs.table.getValue();
		if(_values && _values.length){
			zn.confirm('确认删除这' + _values.length + '个用户吗？', '提示', function () {
				zn.http.post('/zn.plugin.admin/model/delete', {
					model: this.props.model,
					where: "id in (" + _values.join(',') + ")"
				}).then(function (data){
					if(data.status==200){
						zn.toast.success('删除成功');
						_self.state.data.refresh();
					}else {
						zn.toast.error('删除失败: ' + data.result);
					}
				}, function (data){
					zn.toast.error('服务器错误：删除失败');
				});
			}.bind(this));
		}else {
			zn.toast.warning('请先选择要删除的用户');
		}
	},
	__onToolbarClick: function (item){
		switch (item.name) {
			case 'wfinstance.create':
				this.__createInstance();
				break;
			case 'wfinstance.delete':
				this.__removeItems();
				break;
		}
	},
	__onTableColumnRender: function (rowIndex, columnIndex, data, item, value){
		switch (columnIndex) {
			case 2:
				return <a href={'#'+zn.react.session.fixPath('/znpluginworkflow.WFInstance')+'?instanceId=' + data.id}>{value}</a>;
			case 3:
				switch (value) {
					case 1:
						return <span className="status" style={{backgroundColor: '#f0ad4e'}}>待处理</span>;
					case -1:
						return <span className="status" style={{backgroundColor: '#6def55'}}>已结束</span>;
					case -2:
						return <span className="status" style={{backgroundColor: '#dad8d8'}}>已取消</span>;
					case 2:
						return <span className="status" style={{backgroundColor: '#0d8c06'}}>已审核</span>;
				}
				break;
		}
	},
	render:function(){
		return (
			<zn.react.Page className="zn-plugin-workflow-wf-my" title="流程列表" toolbarItems={this.state.toolbarItems} onToolbarClick={this.__onToolbarClick}>
				<zn.react.PagerView
					ref="table"
					view="Table"
					enableFilter={true}
					checkbox={50}
					showHeader={true}
					columnRender={this.__onTableColumnRender}
					data={this.state.data}
					items={this.state.items}/>
			</zn.react.Page>
		);
	}
});

==> zn-plugin-workflow-0.2.0.tgz: package/web/src/component/WFInstanceList.js <==
var React = require('react');
var CreateInstance = require('./CreateInstance');
module.exports = React.createClass({
	getDefaultProps: function () {
		return {
			model: 'ZNPluginWorkflowInstance'
		};
	},
	getInitialState: function () {
		return {
			data: zn.store.post('/zn.plugin.workflow/wfinstance/getInstances', {
				index_id: this.props.indexId
			}),
			items: [
				{ title: '模块', name: 'index_id_convert', width: 80 },
				{ title: '单号', name: 'code', width: 150 },
				{ title: '状态', name: 'state', width: 80 },
				{ title: '当前节点', name: 'current_state', width: 120 },
				{ title: '申请人', name: 'zn_create_user_convert', width: 100 },
				{ title: '申请时间', name: 'zn_create_time', width: 130 },
				{ title: '最近一次操作时间', name: 'zn_modify_time', width: 130 },
				{ title: '说明', name: 'zn_note' }
			],
			toolbarItems: [
				{ text: '创建实例', name: 'wfinstance.create', icon: 'fa-plus', style: { marginRight: 5 } },
				{ text: '删除实例', name: 'wfinstance.delete', status: 'danger', icon: 'fa-remove', style: { marginRight: 5 } }
			]
		}
	},
	componentWillReceiveProps: function (nextProps){
		if(nextProps.indexId){
			this.state.data.extend({
				index_id: nextProps.indexId
			}).refresh();
		}
	},
	__doSuccess: function (){
		this.state.data.refresh();
	},
	__createInstance: function (){
		zn.dialog({
			title: '创建流程实例',
			content: <CreateInstance id={this.props.indexId} />
		});
	},
	__removeItems: function (){
		var _self = this,
			_values = this.refs.table.getValue();
		if(_values && _values.length){
			zn.confirm('确认删除这' + _values.length + '个用户吗？', '提示', function () {
				zn.http.post('/zn.plugin.admin/model/delete', {
					model: this.props.model,
					where: "id in (" + _values.join(',') + ")"
				}).then(function (data){
					if(data.status==200){
						zn.toast.success('删除成功');
						_self.state.data.refresh();
					}else {
						zn.toast.error('删除失败: ' + data.result);
					}
				}, function (data){
					zn.toast.error('服务器错误：删除失败');
				});
			}.bind(this));
		}else {
			zn.toast.warning('请先选择要删除的用户');
		}
	},
	__onToolbarClick: function (item){
		switch (item.name) {
			case 'wfinstance.create':
				this.__createInstance();
				break;
			case 'wfinstance.delete':
				this.__removeItems();
				break;
		}
	},
	__onTableColumnRender: function (rowIndex, columnIndex, data, item, value){
		switch (columnIndex) {
			case 2:
				return <a href={'#'+zn.react.session.fixPath('/znpluginworkflow.wfinstance')+'?instanceId=' + data.id}>{value}</a>;
			case 3:
				switch (value) {
					case 1:
						return <span className="status" style={{backgroundColor: '#f0ad4e'}}>待处理</span>;
					case -1:
						return <span className="status" style={{backgroundColor: '#6def55'}}>已结束</span>;
					case -2:
						return <span className="status" style={{backgroundColor: '#dad8d8'}}>已取消</span>;
					case 2:
						return <span className="status" style={{backgroundColor: '#0d8c06'}}>已审核</span>;
				}
				break;
		}
	},
	render:function(){
		return (
			<zn.react.Page className="zn-plugin-workflow-wf-my" title="流程列表" toolbarItems={this.state.toolbarItems} onToolbarClick={this.__onToolbarClick}>
				<zn.react.PagerView
					ref="table"
					view="Table"
					enableFilter={true}
					checkbox={50}
					showHeader={true}
					columnRender={this.__onTableColumnRender}
					data={this.state.data}
					items={this.state.items}/>
			</zn.react.Page>
		);
	}
});
